@@ -164,7 +164,7 @@ ffirst.lag<- function(PKindex,
                Domains=matrix(c(0.01,0.01,1,10,1,100),3,2),
                MemoryMatrix=TRUE)
       }
-      cat("<< The value of parameter fitted by genetic algorithm >>\n\n")
+      cat("<< The value of parameter obtained from genetic algorithm >>\n\n")
       if (MMe) {
         namegen<-c("ka","Vm","Km","Vd")
         outgen<-c(gen$par[1],gen$par[2],gen$par[3],gen$par[4])
