@@ -120,7 +120,7 @@ fzero.nolag <- function(PKindex,
               MemoryMatrix=TRUE)
       }
       
-     cat("<< The value of parameter fitted by genetic algorithm >>\n\n")
+     cat("<< The value of parameter obtained from genetic algorithm >>\n\n")
      if (MMe) {
         namegen<-c("Tabs","Vm","Km","Vd")
         outgen<-c(gen$par[1],gen$par[2],gen$par[3],gen$par[4])
